@@ -1,22 +1,18 @@
 package MooseX::Singleton;
-
-use Moose ();
-use Moose::Exporter;
+use Moose;
 use MooseX::Singleton::Object;
 use MooseX::Singleton::Meta::Class;
 
-our $VERSION = '0.09_02';
-$VERSION = eval $VERSION;
+our $VERSION = 0.03;
 
-Moose::Exporter->setup_import_methods( also => 'Moose' );
+sub import {
+    my $caller = caller;
 
-sub init_meta {
-    shift;
-    Moose->init_meta(
-        @_,
-        base_class => 'MooseX::Singleton::Object',
-        metaclass  => 'MooseX::Singleton::Meta::Class',
-    );
+    Moose::init_meta($caller, 'MooseX::Singleton::Object', 'MooseX::Singleton::Meta::Class');
+
+    Moose->import({into => $caller});
+    strict->import;
+    warnings->import;
 }
 
 1;
@@ -31,7 +27,7 @@ MooseX::Singleton - turn your Moose class into a singleton
 
 =head1 VERSION
 
-Version 0.08, released 24 May 08
+Version 0.03, released 16 Dec 07
 
 =head1 SYNOPSIS
 
@@ -94,15 +90,9 @@ Shawn M Moore E<lt>sartak@gmail.comE<gt>
 
 Anders Nor Berle E<lt>debolaz@gmail.comE<gt>
 
-=head1 AND PATCHES FROM
-
-Ricardo SIGNES E<lt>rjbs@cpan.orgE<gt>
-
-Dave Rolsky E<lt>autarch@urth.orgE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007, 2008 Shawn M Moore.
+Copyright 2007 Shawn M Moore.
 
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
